The following list of users have significantly contributed to the code
and/or design of snake-guice. They are order by the date of their first
contribution.

`David Stanek <http://dstanek.com>`_
`Mike Crute <http://mike.crute.org`_
